import gtk
import gtk.glade

# The new task assistant's class.
class PyAtCronNewTask:

	def __init__ (self, parent):

		# This is the current page.
		self.currentPage = 1

		# This is the last page.
		self.lastPage = 1

		# This is the previously displayed page
		self.oldPage = None

		# We load the widgets and the callbacks from the glade file.
		self.widgetTree = gtk.glade.XML ("newtask.glade")
		dic = {
						"on_newtask_delete_event" : self.deleteEvent,
						"on_cancel_button_clicked" : self.cancelClicked,
						"on_back_button_clicked" : self.backClicked,
						"on_forward_button_clicked" : self.forwardClicked
					}
		self.widgetTree.signal_autoconnect (dic)

		# It's the base widget.
		self.win = self.widgetTree.get_widget ("newtask")

		# If a parent is specified, center the window on it.
		if parent:
			self.win.set_transient_for (parent)
			self.win.set_position (gtk.WIN_POS_CENTER_ON_PARENT)

		# Sets the color of the title bar.
		self.widgetTree.get_widget ("titlebar").modify_bg (gtk.STATE_NORMAL, gtk.gdk.color_parse ("#707070"))

		# We define 3 pages. Each page is a label.
		self.pages = {
							1 : gtk.Label ("This is page 1"),
							2 : gtk.Label ("This is page 2"),
							3 : gtk.Label ("This is page 3")
						}
		self.lastPage = 3

		# Displays the assistant.
		self.win.show ()

		# Update the currently viewed page
		self.updatePage ()

	def deleteEvent (self, obj, event):
		self.quit ()

	def backClicked (self, obj):
		self.goBack ()

	def forwardClicked (self, obj):
		self.goForward ()

	def cancelClicked (self, obj):
		self.quit ()

	def goBack (self):
		# If we're not on the first page, go back
		if (self.currentPage > 1):
			print "TODO: go back"
			self.currentPage = self.currentPage - 1
			self.updatePage ()

	def goForward (self):
		# If we're not on the last page, go forward. Else, finish with the assistant.
		if (self.currentPage < self.lastPage):
			print "TODO: go forward"
			self.currentPage = self.currentPage + 1
			self.updatePage ()
		else:
			print "TODO: finish"
			self.quit ()

	def updatePage (self):
		# If we are of the first page, make the back button insensitive.
		self.widgetTree.get_widget ("back_button").set_sensitive (self.currentPage != 1)

		# If we are of the last page, the button's text to "OK". Else, it's "Forward".
		self.widgetTree.get_widget ("forward_button").set_use_stock (True)
		if (self.currentPage == self.lastPage):
			self.widgetTree.get_widget ("forward_button").set_label (eval('gtk.STOCK_OK'))
		else:
			self.widgetTree.get_widget ("forward_button").set_label (eval('gtk.STOCK_GO_FORWARD'))

		# If we currently have a page displayed, remove it.
		if (self.oldPage != None):
			self.widgetTree.get_widget ("mainbox").remove (self.oldPage)

		# Add the current page to the dialog, and display it.
		page = self.pages [self.currentPage]
		self.widgetTree.get_widget ("mainbox").add (page)
		page.show ()

		# Save this page, to remove it before displayed the next page.
		self.oldPage = page

	# Unreferences the main window's widgets.
	def quit (self):
		self.win.destroy ()
